package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Sep 1, 2026
License: MIT
Opens a new window with license information.
Imports: 17
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package validate provides pure value predicates and a stable rule catalog.
Is applies one named pure validation rule.
Options returns the Expr registrations for validation helpers.
type Rule struct {
Name string `json:"name"`
Summary string `json:"summary"`
Example string `json:"example"`
}
Rule describes one expression validation rule.
Rules returns the stable, alphabetically ordered validation catalog.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.