Documentation
¶
Overview ¶
Package collection provides bounded, deterministic collection operations.
Index ¶
- func Chunk(values []any, size int) ([][]any, error)
- func Cumsum(values []any) ([]float64, error)
- func Diff(values []any) ([]float64, error)
- func Difference(left, right []any) ([]any, error)
- func Intersection(left, right []any) ([]any, error)
- func Lag(values []any, periods int) ([]any, error)
- func Merge(left, right map[string]any) (map[string]any, error)
- func Options() []exprlib.Option
- func Union(left, right []any) ([]any, error)
- func Zip(left, right []any) ([][]any, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Difference ¶
Difference returns unique values from left that are absent from right.
func Intersection ¶
Intersection returns unique values present in both inputs, preserving left order.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.